summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLynx Linden <lynx@lindenlab.com>2010-02-04 10:23:24 +0000
committerLynx Linden <lynx@lindenlab.com>2010-02-04 10:23:24 +0000
commit6c992c95a98ec69e77455129098338dce2f092aa (patch)
tree206905ea52ce14bf848e491e979f839ad5f7bf71
parentf7120956f50afb3ffae269819ffbd7f07b1ac85b (diff)
EXT-3681: Send Parcel "Local ID" (S32) to web pages.
This is instead of sending the Parcel ID (LLUUID), which it turns out the server never sends to the viewer (LLParcel::getID() always returns NULL).
-rw-r--r--indra/newview/llweb.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/indra/newview/llweb.cpp b/indra/newview/llweb.cpp
index 3def17f33c..100ec0bb69 100644
--- a/indra/newview/llweb.cpp
+++ b/indra/newview/llweb.cpp
@@ -168,14 +168,14 @@ std::string LLWeb::expandURLSubstitutions(const std::string &url,
}
substitution["REGION_ID"] = region_id;
- // find the parcel ID
- LLUUID parcel_id;
+ // find the parcel local ID
+ S32 parcel_id = 0;
LLParcel* parcel = LLViewerParcelMgr::getInstance()->getAgentParcel();
if (parcel)
{
- parcel_id = parcel->getID();
+ parcel_id = parcel->getLocalID();
}
- substitution["PARCEL_ID"] = parcel_id;
+ substitution["PARCEL_ID"] = llformat("%d", parcel_id);
// expand all of the substitution strings and escape the url
std::string expanded_url = url;